@@ -42,7 +42,14 @@ sub pre_action {
     $create  = $session->get('create');
     $access  = $session->get('access');
 
-    $session->set('user', $self->scaffold->request->user) if (not $user);
+    if (not $user) {
+
+        $user = defined($self->scaffold->request->user) ? 
+          $self->scaffold->request->user : 'guest';
+
+    }
+
+    $session->set('user', $user);
     $session->set('address', $self->scaffold->request->address) if (not $address);
     $session->set('create', time()) if (not $create);
     $session->set('access', time()) if (not $access);
@@ -57,14 +64,19 @@ sub pre_action {
 sub pre_exit {
     my ($self, $hobj) = @_;
 
-    my $session = $self->scaffold->session;
-    my $lockmgr = $self->scaffold->lockmgr;
+    my $session  = $self->scaffold->session;
+    my $lockmgr  = $self->scaffold->lockmgr;
     my $response = $self->scaffold->response;
 
-    $lockmgr->deallocate($session->session_id);
     $session->set('access', time());
-    $session->response_filter($response);
 
+    if (defined($session->session_id)) {
+
+        $lockmgr->deallocate($session->session_id);
+
+    }
+
+    $session->response_filter($response);
     $session->finalize();          # must be the last thing done!!
 
     return PLUGIN_NEXT;
@@ -127,6 +139,7 @@ temporary cookies.
  Scaffold::Render
  Scaffold::Render::Default
  Scaffold::Render::TT
+ Scaffold::Routes
  Scaffold::Server
  Scaffold::Session::Manager
  Scaffold::Stash
@@ -146,7 +159,7 @@ temporary cookies.
 
 =head1 AUTHOR
 
-Kevin L. Esteb, E<lt>kesteb@wsipc.orgE<gt>
+Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
